==> parodia_admin-1.0.2.tar.gz: lib/core/repository/storeShipmentMethod.repository.dart <==
// GET
// /api/v1/dashboard/stores/shipment_methods/{id}

// PUT
// /api/v1/dashboard/stores/shipment_methods/{id}

// DELETE
// /api/v1/dashboard/stores/shipment_methods/{id}

// GET
// /api/v1/dashboard/stores/shipment_methods

// POST
// /api/v1/dashboard/stores/shipment_methods

// POST
// /api/v1/dashboard/stores/shipment_methods/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/shipment_method.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StoreShipmentMethodRepository {
  ParodiaHTTP? _http;

  StoreShipmentMethodRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ShipmentMethodDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/stores/shipment_methods',
      param: id,
    );

    return ResponseItemDTO<ShipmentMethodDTO>(
      response: response,
      fromJson: ShipmentMethodDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ShipmentMethodDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/stores/shipment_methods',
      query: query,
    );

    return ResponseListDTO<ShipmentMethodDTO>(
      response: response,
      fromJson: ShipmentMethodDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create(
      {StoreShipmentMethodBody? shipmentMethod}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/stores/shipment_methods',
      data: shipmentMethod,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> update(
      {StoreShipmentMethodBody? shipmentMethod, String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/stores/shipment_methods',
      param: id,
      data: shipmentMethod,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/stores/shipment_methods',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/stores/shipment_methods/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/storeShipmentMethod.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/stores/shipment_methods/{id}

// PUT
// /api/v1/dashboard/dashboard/stores/shipment_methods/{id}

// DELETE
// /api/v1/dashboard/dashboard/stores/shipment_methods/{id}

// GET
// /api/v1/dashboard/dashboard/stores/shipment_methods

// POST
// /api/v1/dashboard/dashboard/stores/shipment_methods

// POST
// /api/v1/dashboard/dashboard/stores/shipment_methods/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/shipment_method.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StoreShipmentMethodRepository {
  ParodiaHTTP? _http;

  StoreShipmentMethodRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ShipmentMethodDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stores/shipment_methods',
      param: id,
    );

    return ResponseItemDTO<ShipmentMethodDTO>(
      response: response,
      fromJson: ShipmentMethodDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ShipmentMethodDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stores/shipment_methods',
      query: query,
    );

    return ResponseListDTO<ShipmentMethodDTO>(
      response: response,
      fromJson: ShipmentMethodDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create(
      {StoreShipmentMethodBody? shipmentMethod}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/stores/shipment_methods',
      data: shipmentMethod,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> update(
      {StoreShipmentMethodBody? shipmentMethod, String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/stores/shipment_methods',
      param: id,
      data: shipmentMethod,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/stores/shipment_methods',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/stores/shipment_methods/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
    );
  }
}
